(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue-clickaway')) :
  typeof define === 'function' && define.amd ? define(['exports', 'vue-clickaway'], factory) :
  (factory((global.VueBootstrapSelect = {}),global.vueClickaway));
}(this, (function (exports,vueClickaway) { 'use strict';

  //

  var script = {
    name: "VSelect",
    mixins: [vueClickaway.mixin],
    props: {
      labelTitle: {
        type: String,
        default: "Nothing selected"
      },
      labelNotFound: {
        type: String,
        default: "No results matched"
      },
      labelSearchPlaceholder: {
        type: String,
        default: "Search"
      },
      options: {
        type: Array,
        default: function () { return []; }
      },
      searchable: {
        type: Boolean,
        default: false
      },
      showDefaultOption: {
        type: Boolean,
        default: false
      },
      textProp: {
        type: String,
        default: "text"
      },
      value: {
        type: [Object, String, Number],
        default: null
      },
      valueProp: {
        type: String,
        default: "value"
      }
    },
    data: function data() {
      return {
        show: false,
        selectedValue: this.value,
        searchValue: ""
      };
    },
    computed: {
      filteredProps: function filteredProps() {
        var this$1 = this;

        if (this.searchable && this.searchValue.length > 0) {
          return this.options.filter(function (item) {
            if (typeof item === "object") {
              return (
                item[this$1.textProp]
                  .toLowerCase()
                  .indexOf(this$1.searchValue.toLowerCase()) !== -1
              );
            } else {
              return (
                item.toLowerCase().indexOf(this$1.searchValue.toLowerCase()) !== -1
              );
            }
          });
        }
        return this.options;
      }
    },
    methods: {
      handleSelect: function handleSelect(option) {
        this.selectedValue = option;
        this.hideDropdown();
        this.$emit("input", option);
      },
      hideDropdown: function hideDropdown() {
        this.show = false;
        this.searchValue = "";
      },
      getOptionLabel: function getOptionLabel(option) {
        if (typeof option === "object") {
          return option[this.textProp];
        }
        return option;
      }
    }
  };

  /* script */
              var __vue_script__ = script;
              
  /* template */
  var __vue_render__ = function() {
    var _vm = this;
    var _h = _vm.$createElement;
    var _c = _vm._self._c || _h;
    return _c(
      "div",
      {
        directives: [
          {
            name: "on-clickaway",
            rawName: "v-on-clickaway",
            value: _vm.hideDropdown,
            expression: "hideDropdown"
          }
        ],
        staticClass: "v-select"
      },
      [
        _c(
          "div",
          {
            staticClass: "v-select-toggle",
            on: {
              click: function($event) {
                _vm.show = !_vm.show;
              }
            }
          },
          [
            _c("div", [
              _vm._v(
                "\n            " +
                  _vm._s(
                    _vm.selectedValue
                      ? _vm.getOptionLabel(_vm.selectedValue)
                      : _vm.labelTitle
                  ) +
                  "\n        "
              )
            ]),
            _vm._v(" "),
            _c("div", { staticClass: "arrow-down" })
          ]
        ),
        _vm._v(" "),
        _c(
          "div",
          {
            directives: [
              {
                name: "show",
                rawName: "v-show",
                value: _vm.show,
                expression: "show"
              }
            ],
            staticClass: "v-dropdown-container"
          },
          [
            _c(
              "div",
              {
                directives: [
                  {
                    name: "show",
                    rawName: "v-show",
                    value: _vm.searchable,
                    expression: "searchable"
                  }
                ],
                staticClass: "bs-searchbox"
              },
              [
                _c("input", {
                  directives: [
                    {
                      name: "model",
                      rawName: "v-model",
                      value: _vm.searchValue,
                      expression: "searchValue"
                    }
                  ],
                  staticClass: "form-control",
                  attrs: {
                    placeholder: _vm.labelSearchPlaceholder,
                    type: "text",
                    autofocus: ""
                  },
                  domProps: { value: _vm.searchValue },
                  on: {
                    input: function($event) {
                      if ($event.target.composing) {
                        return
                      }
                      _vm.searchValue = $event.target.value;
                    }
                  }
                })
              ]
            ),
            _vm._v(" "),
            _c(
              "ul",
              [
                _c(
                  "li",
                  {
                    directives: [
                      {
                        name: "show",
                        rawName: "v-show",
                        value: _vm.searchable && _vm.filteredProps.length === 0,
                        expression: "searchable && filteredProps.length === 0"
                      }
                    ],
                    staticClass: "v-dropdown-item"
                  },
                  [
                    _vm._v(
                      "\n                " +
                        _vm._s(_vm.labelNotFound) +
                        ' "' +
                        _vm._s(_vm.searchValue) +
                        '"\n            '
                    )
                  ]
                ),
                _vm._v(" "),
                _vm.showDefaultOption
                  ? _c(
                      "li",
                      { staticClass: "v-dropdown-item disabled default-option" },
                      [
                        _vm._v(
                          "\n                " +
                            _vm._s(_vm.labelTitle) +
                            "\n            "
                        )
                      ]
                    )
                  : _vm._e(),
                _vm._v(" "),
                _vm._l(_vm.filteredProps, function(option, index) {
                  return _c(
                    "li",
                    {
                      key: "v-select-" + index,
                      staticClass: "v-dropdown-item",
                      class: {
                        selected:
                          _vm.selectedValue && option === _vm.selectedValue
                      },
                      on: {
                        click: function($event) {
                          return _vm.handleSelect(option)
                        }
                      }
                    },
                    [
                      _vm._v(
                        "\n                " +
                          _vm._s(_vm.getOptionLabel(option)) +
                          "\n            "
                      )
                    ]
                  )
                })
              ],
              2
            )
          ]
        )
      ]
    )
  };
  var __vue_staticRenderFns__ = [];
  __vue_render__._withStripped = true;

    /* style */
    var __vue_inject_styles__ = function (inject) {
      if (!inject) { return }
      inject("data-v-482e9062_0", { source: "\n*[data-v-482e9062] {\n  box-sizing: border-box;\n}\n.v-select[data-v-482e9062] {\n  position: relative;\n  width: 100%;\n  height: 30px;\n  background-color: #f8f9fa;\n  border-color: #f8f9fa;\n  border-radius: 0.25rem;\n  line-height: 1.5;\n  color: #212529;\n  font-size: 12px;\n  transition: background-color, border-color, box-shadow, 0.15s ease-in-out;\n  font-family: inherit, sans-serif;\n  cursor: pointer;\n}\n.v-select[data-v-482e9062]:hover {\n  background-color: #e2e6ea;\n  border-color: #dae0e5;\n}\n.v-select-toggle[data-v-482e9062] {\n  display: flex;\n  justify-content: space-between;\n  user-select: none;\n  padding: 0.375rem 0.75rem;\n}\n.arrow-down[data-v-482e9062] {\n  display: inline-block;\n  width: 0;\n  height: 0;\n  margin-left: 0.255em;\n  margin-top: 7px;\n  vertical-align: 0.255em;\n  content: \"\";\n  border-top: 0.3em solid;\n  border-right: 0.3em solid transparent;\n  border-bottom: 0;\n  border-left: 0.3em solid transparent;\n}\n.v-dropdown-container[data-v-482e9062] {\n  position: absolute;\n  width: 100%;\n  background: red;\n  padding: 0.5rem 0;\n  margin: 0.125rem 0 0;\n  color: #212529;\n  text-align: left;\n  list-style: none;\n  background-color: #fff;\n  background-clip: padding-box;\n  border-radius: 0.25rem;\n  border: 1px solid rgba(0, 0, 0, 0.15);\n  z-index: 1000;\n}\nul[data-v-482e9062] {\n  font-size: 12px;\n  color: #424242;\n  text-align: left;\n  list-style: none;\n  background-color: #fff;\n  background-clip: padding-box;\n  padding: 0px;\n  margin: 0px;\n}\n.v-dropdown-item[data-v-482e9062] {\n  line-height: 25px;\n  padding: 0.5rem 1.25rem;\n  user-select: none;\n}\n.v-dropdown-item[data-v-482e9062]:hover:not(.default-option) {\n  text-decoration: none;\n  background-color: #f8f9fa;\n}\n.v-dropdown-item.disabled[data-v-482e9062] {\n  color: #9a9b9b;\n}\n.v-dropdown-item.selected[data-v-482e9062] {\n  background-color: #007bff;\n  color: #fff;\n}\n.v-dropdown-item.selected[data-v-482e9062]:hover {\n  background-color: #007bff;\n  color: #fff;\n}\n.search-container[data-v-482e9062] {\n  padding: 0.5rem 1.25rem;\n}\ninput[data-v-482e9062] {\n  width: 100%;\n}\n.form-control[data-v-482e9062] {\n  display: block;\n  width: 100%;\n  padding: 0.375rem 0.75rem;\n  font-size: 1rem;\n  line-height: 1.5;\n  color: #495057;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid #ced4da;\n  border-radius: 0.25rem;\n  transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n}\n.bs-searchbox[data-v-482e9062] {\n  padding: 4px 8px;\n}\n.bs-searchbox .form-control[data-v-482e9062] {\n    margin-bottom: 0;\n    width: 100%;\n    float: none;\n}\n\n/*# sourceMappingURL=vue-bootstrap-select.vue.map */", map: {"version":3,"sources":["/Users/luissandoval/Documents/Me/Github/vue-bootstrap-select/src/vue-bootstrap-select.vue","vue-bootstrap-select.vue"],"names":[],"mappings":";AA6IA;EACA,uBAAA;CACA;AAEA;EACA,mBAAA;EACA,YAAA;EACA,aAAA;EACA,0BAAA;EACA,sBAAA;EACA,uBAAA;EACA,iBAAA;EACA,eAAA;EACA,gBAAA;EACA,0EAAA;EACA,iCAAA;EACA,gBAAA;CACA;AAEA;EACA,0BAAA;EACA,sBAAA;CACA;AAEA;EACA,cAAA;EACA,+BAAA;EACA,kBAAA;EACA,0BAAA;CACA;AAEA;EACA,sBAAA;EACA,SAAA;EACA,UAAA;EACA,qBAAA;EACA,gBAAA;EACA,wBAAA;EACA,YAAA;EACA,wBAAA;EACA,sCAAA;EACA,iBAAA;EACA,qCAAA;CACA;AAEA;EACA,mBAAA;EACA,YAAA;EACA,gBAAA;EACA,kBAAA;EACA,qBAAA;EACA,eAAA;EACA,iBAAA;EACA,iBAAA;EACA,uBAAA;EACA,6BAAA;EACA,uBAAA;EACA,sCAAA;EACA,cAAA;CACA;AAEA;EACA,gBAAA;EACA,eAAA;EACA,iBAAA;EACA,iBAAA;EACA,uBAAA;EACA,6BAAA;EACA,aAAA;EACA,YAAA;CACA;AAEA;EACA,kBAAA;EACA,wBAAA;EACA,kBAAA;CACA;AAEA;EACA,sBAAA;EACA,0BAAA;CACA;AAEA;EACA,eAAA;CACA;AAEA;EACA,0BAAA;EACA,YAAA;CACA;AAEA;EACA,0BAAA;EACA,YAAA;CACA;AAEA;EACA,wBAAA;CACA;AAEA;EACA,YAAA;CACA;AAEA;EACA,eAAA;EACA,YAAA;EACA,0BAAA;EACA,gBAAA;EACA,iBAAA;EACA,eAAA;EACA,uBAAA;EACA,6BAAA;EACA,0BAAA;EACA,uBAAA;EACA,yEAAA;CACA;AAEA;EACA,iBAAA;CAOA;AARA;IAIA,iBAAA;IACA,YAAA;IACA,YAAA;CACA;;AC5JA,oDAAoD","file":"vue-bootstrap-select.vue","sourcesContent":[null,"* {\n  box-sizing: border-box; }\n\n.v-select {\n  position: relative;\n  width: 100%;\n  height: 30px;\n  background-color: #f8f9fa;\n  border-color: #f8f9fa;\n  border-radius: 0.25rem;\n  line-height: 1.5;\n  color: #212529;\n  font-size: 12px;\n  transition: background-color, border-color, box-shadow, 0.15s ease-in-out;\n  font-family: inherit, sans-serif;\n  cursor: pointer; }\n\n.v-select:hover {\n  background-color: #e2e6ea;\n  border-color: #dae0e5; }\n\n.v-select-toggle {\n  display: flex;\n  justify-content: space-between;\n  user-select: none;\n  padding: 0.375rem 0.75rem; }\n\n.arrow-down {\n  display: inline-block;\n  width: 0;\n  height: 0;\n  margin-left: 0.255em;\n  margin-top: 7px;\n  vertical-align: 0.255em;\n  content: \"\";\n  border-top: 0.3em solid;\n  border-right: 0.3em solid transparent;\n  border-bottom: 0;\n  border-left: 0.3em solid transparent; }\n\n.v-dropdown-container {\n  position: absolute;\n  width: 100%;\n  background: red;\n  padding: 0.5rem 0;\n  margin: 0.125rem 0 0;\n  color: #212529;\n  text-align: left;\n  list-style: none;\n  background-color: #fff;\n  background-clip: padding-box;\n  border-radius: 0.25rem;\n  border: 1px solid rgba(0, 0, 0, 0.15);\n  z-index: 1000; }\n\nul {\n  font-size: 12px;\n  color: #424242;\n  text-align: left;\n  list-style: none;\n  background-color: #fff;\n  background-clip: padding-box;\n  padding: 0px;\n  margin: 0px; }\n\n.v-dropdown-item {\n  line-height: 25px;\n  padding: 0.5rem 1.25rem;\n  user-select: none; }\n\n.v-dropdown-item:hover:not(.default-option) {\n  text-decoration: none;\n  background-color: #f8f9fa; }\n\n.v-dropdown-item.disabled {\n  color: #9a9b9b; }\n\n.v-dropdown-item.selected {\n  background-color: #007bff;\n  color: #fff; }\n\n.v-dropdown-item.selected:hover {\n  background-color: #007bff;\n  color: #fff; }\n\n.search-container {\n  padding: 0.5rem 1.25rem; }\n\ninput {\n  width: 100%; }\n\n.form-control {\n  display: block;\n  width: 100%;\n  padding: 0.375rem 0.75rem;\n  font-size: 1rem;\n  line-height: 1.5;\n  color: #495057;\n  background-color: #fff;\n  background-clip: padding-box;\n  border: 1px solid #ced4da;\n  border-radius: 0.25rem;\n  transition: border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out; }\n\n.bs-searchbox {\n  padding: 4px 8px; }\n  .bs-searchbox .form-control {\n    margin-bottom: 0;\n    width: 100%;\n    float: none; }\n\n/*# sourceMappingURL=vue-bootstrap-select.vue.map */"]}, media: undefined });

    };
    /* scoped */
    var __vue_scope_id__ = "data-v-482e9062";
    /* module identifier */
    var __vue_module_identifier__ = undefined;
    /* functional template */
    var __vue_is_functional_template__ = false;
    /* component normalizer */
    function __vue_normalize__(
      template, style, script$$1,
      scope, functional, moduleIdentifier,
      createInjector, createInjectorSSR
    ) {
      var component = (typeof script$$1 === 'function' ? script$$1.options : script$$1) || {};

      // For security concerns, we use only base name in production mode.
      component.__file = "/Users/luissandoval/Documents/Me/Github/vue-bootstrap-select/src/vue-bootstrap-select.vue";

      if (!component.render) {
        component.render = template.render;
        component.staticRenderFns = template.staticRenderFns;
        component._compiled = true;

        if (functional) { component.functional = true; }
      }

      component._scopeId = scope;

      {
        var hook;
        if (style) {
          hook = function(context) {
            style.call(this, createInjector(context));
          };
        }

        if (hook !== undefined) {
          if (component.functional) {
            // register for functional component in vue file
            var originalRender = component.render;
            component.render = function renderWithStyleInjection(h, context) {
              hook.call(context);
              return originalRender(h, context)
            };
          } else {
            // inject component registration as beforeCreate hook
            var existing = component.beforeCreate;
            component.beforeCreate = existing ? [].concat(existing, hook) : [hook];
          }
        }
      }

      return component
    }
    /* style inject */
    function __vue_create_injector__() {
      var head = document.head || document.getElementsByTagName('head')[0];
      var styles = __vue_create_injector__.styles || (__vue_create_injector__.styles = {});
      var isOldIE =
        typeof navigator !== 'undefined' &&
        /msie [6-9]\\b/.test(navigator.userAgent.toLowerCase());

      return function addStyle(id, css) {
        if (document.querySelector('style[data-vue-ssr-id~="' + id + '"]')) { return } // SSR styles are present.

        var group = isOldIE ? css.media || 'default' : id;
        var style = styles[group] || (styles[group] = { ids: [], parts: [], element: undefined });

        if (!style.ids.includes(id)) {
          var code = css.source;
          var index = style.ids.length;

          style.ids.push(id);

          if (isOldIE) {
            style.element = style.element || document.querySelector('style[data-group=' + group + ']');
          }

          if (!style.element) {
            var el = style.element = document.createElement('style');
            el.type = 'text/css';

            if (css.media) { el.setAttribute('media', css.media); }
            if (isOldIE) {
              el.setAttribute('data-group', group);
              el.setAttribute('data-next-index', '0');
            }

            head.appendChild(el);
          }

          if (isOldIE) {
            index = parseInt(style.element.getAttribute('data-next-index'));
            style.element.setAttribute('data-next-index', index + 1);
          }

          if (style.element.styleSheet) {
            style.parts.push(code);
            style.element.styleSheet.cssText = style.parts
              .filter(Boolean)
              .join('\n');
          } else {
            var textNode = document.createTextNode(code);
            var nodes = style.element.childNodes;
            if (nodes[index]) { style.element.removeChild(nodes[index]); }
            if (nodes.length) { style.element.insertBefore(textNode, nodes[index]); }
            else { style.element.appendChild(textNode); }
          }
        }
      }
    }
    /* style inject SSR */
    

    
    var component = __vue_normalize__(
      { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
      __vue_inject_styles__,
      __vue_script__,
      __vue_scope_id__,
      __vue_is_functional_template__,
      __vue_module_identifier__,
      __vue_create_injector__,
      undefined
    );

  // Import vue component

  // install function executed by Vue.use()
  function install(Vue) {
    if (install.installed) { return; }
    install.installed = true;
    Vue.component('VueBootstrapSelect', component);
  }

  // Create module definition for Vue.use()
  var plugin = {
    install: install,
  };

  // To auto-install when vue is found
  /* global window global */
  var GlobalVue = null;
  if (typeof window !== 'undefined') {
    GlobalVue = window.Vue;
  } else if (typeof global !== 'undefined') {
    GlobalVue = global.Vue;
  }
  if (GlobalVue) {
    GlobalVue.use(plugin);
  }

  // It's possible to expose named exports when writing components that can
  // also be used as directives, etc. - eg. import { RollupDemoDirective } from 'rollup-demo';
  // export const RollupDemoDirective = component;

  exports.default = component;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
